@@ -4,7 +4,7 @@ use warnings;
 use utf8;
 
 package Dist::Zilla::Plugin::Prereqs::Soften;
-$Dist::Zilla::Plugin::Prereqs::Soften::VERSION = '0.002000';
+$Dist::Zilla::Plugin::Prereqs::Soften::VERSION = '0.003000';
 # ABSTRACT: Downgrade listed dependencies to recommendations if present.
 
 our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
@@ -30,6 +30,8 @@ with 'Dist::Zilla::Role::PrereqSource';
 
 
 
+
+
 has 'modules' => (
   is => ro =>,
   isa => ArrayRef [Str],
@@ -64,15 +66,70 @@ has 'to_relationship' => (
 
 no Moose::Util::TypeConstraints;
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+has 'copy_to' => (
+  is      => 'ro',
+  isa     => ArrayRef [Str],
+  lazy    => 1,
+  default => sub { [] },
+);
+
+has '_copy_to_extras' => (
+  is      => 'ro',
+  isa     => ArrayRef [HashRef],
+  lazy    => 1,
+  builder => '_build__copy_to_extras',
+);
+
 has '_modules_hash' => (
   is      => ro                   =>,
   isa     => HashRef,
   lazy    => 1,
   builder => _build__modules_hash =>,
 );
-sub mvp_multivalue_args { return qw(modules) }
+sub mvp_multivalue_args { return qw(modules copy_to) }
 sub mvp_aliases { return { 'module' => 'modules' } }
 
+sub _build__copy_to_extras {
+  my $self = shift;
+  my $to   = [];
+  for my $copy ( @{ $self->copy_to } ) {
+    next unless ( my ( $copy_phase, $copy_rel ) = $copy =~ /\A([^.]+)[.](.+)\z/msx );
+    push @{$to}, { phase => $copy_phase, relation => $copy_rel };
+  }
+  return $to;
+}
+
 sub _build__modules_hash {
   my $self = shift;
   return { map { ( $_, 1 ) } @{ $self->modules } };
@@ -88,6 +145,7 @@ around dump_config => sub {
   my $this_config = {
     modules         => $self->modules,
     to_relationship => $self->to_relationship,
+    copy_to         => $self->copy_to,
   };
   $config->{ q{} . __PACKAGE__ } = $this_config;
   return $config;
@@ -98,13 +156,20 @@ sub _soften_prereqs {
   my $prereqs = $self->zilla->prereqs;
 
   my $source_reqs = $prereqs->requirements_for( $conf->{from_phase}, $conf->{from_relation} );
-  my $target_reqs = $prereqs->requirements_for( $conf->{to_phase},   $conf->{to_relation} );
+
+  my @target_reqs;
+
+  for my $target ( @{ $conf->{to} } ) {
+    push @target_reqs, $prereqs->requirements_for( $target->{phase}, $target->{relation} );
+  }
 
   for my $module ( $source_reqs->required_modules ) {
     next unless $self->_user_wants_softening_on($module);
     my $reqstring = $source_reqs->requirements_for_module($module);
     $source_reqs->clear_requirement($module);
-    $target_reqs->add_string_requirement( $module, $reqstring );
+    for my $target (@target_reqs) {
+      $target->add_string_requirement( $module, $reqstring );
+    }
   }
   return $self;
 }
@@ -118,8 +183,7 @@ sub register_prereqs {
         {
           from_phase    => $phase,
           from_relation => $relation,
-          to_phase      => $phase,
-          to_relation   => $self->to_relationship,
+          to            => [ { phase => $phase, relation => $self->to_relationship }, @{ $self->_copy_to_extras }, ],
         },
       );
     }
@@ -152,7 +216,7 @@ Dist::Zilla::Plugin::Prereqs::Soften - Downgrade listed dependencies to recommen
 
 =head1 VERSION
 
-version 0.002000
+version 0.003000
 
 =head1 SYNOPSIS
 
@@ -160,8 +224,10 @@ version 0.002000
     module = Foo
     module = Bar
 
-This module iterates C<build>, C<require> and C<test> dependency lists
-and migrates dependencies found in C<.requires> and demotes them to C<.recommends>
+This module iterates C<build>, C<require> and C<test> dependency lists and migrates dependencies found in C<.requires> and
+demotes them to C<.recommends>
+
+Optionally, it can L<< duplicate softened dependencies to other locations|/copy_to >>
 
 =head1 ATTRIBUTES
 
@@ -183,6 +249,35 @@ B<Valid Values:>
 
 Though the last two are reserved for people with C<< $num_feet > 2 >> or with shotguns that only fire blanks.
 
+=head2 C<copy_to>
+
+Additional places to copy the dependency to:
+
+B<Default:>
+
+    []
+
+B<Example:>
+
+    [Prereqs::Soften]
+    copy_to         = develop.requires
+    to_relationship = recommends
+    module          = Foo
+
+This in effect means:
+
+    remove from: runtime.requires
+        → add to: develop.requires
+        → add to: runtime.recommends
+
+    remove from: test.requires
+        → add to: develop.requires
+        → add to: test.recommends
+
+     remove from: build.requires
+        → add to: develop.requires
+        → add to: build.recommends
+
 =for Pod::Coverage mvp_aliases
 mvp_multivalue_args
 register_prereqs
